Use /data if it exists and is writeable, otherwise use /usr/tmp to
authorMarc Fiuczynski <mef@cs.princeton.edu>
Wed, 24 Oct 2007 21:25:16 +0000 (21:25 +0000)
committerMarc Fiuczynski <mef@cs.princeton.edu>
Wed, 24 Oct 2007 21:25:16 +0000 (21:25 +0000)
build images.

build.sh

index 0e1f598..c150605 100755 (executable)
--- a/build.sh
+++ b/build.sh
@@ -100,12 +100,19 @@ FULL_VERSION_STRING="$PLC_NAME BootCD $BOOTCD_VERSION"
 
 echo "* Building images for $FULL_VERSION_STRING"
 
# From within a myplc chroot /tmp is too small to build
# all possible images, whereas /data is part of the host
 # filesystem and usually has sufficient space.  What we
 # should do is check whether the expected amount of space
 # is available.
-[ -d /data ] && BUILDTMP=/data || BUILDTMP=/tmp
+BUILDTMP=/usr/tmp
+if [ -d /data ] ; then
+       isreadonly=$(mktemp /data/isreadonly.XXXXXX)
+       if [ $? -eq 0 ] ; then
+               rm -f "$isreadonly"
+               BUILDTMP=/data
+       fi
+fi
 
 # Root of the ISO and USB images
 echo "* Populating root filesystem..."
@@ -100,12 +100,19 @@ FULL_VERSION_STRING="$PLC_NAME BootCD $BOOTCD_VERSION"
 echo "* Building images for $FULL_VERSION_STRING"
 
-# From within a myplc chroot /tmp is too small to build
-# all possible images, whereas /data is part of the host
+# From within a myplc chroot /usr/tmp is too small 
+# to build all possible images, whereas /data is part of the host
 # filesystem and usually has sufficient space.  What we
 # should do is check whether the expected amount of space